============
python-ufile
============


.. image:: https://img.shields.io/pypi/v/python_ufile.svg
        :target: https://pypi.python.org/pypi/python_ufile

.. image:: https://img.shields.io/travis/AriaBagheri/python_ufile.svg
        :target: https://travis-ci.com/AriaBagheri/python_ufile

.. image:: https://readthedocs.org/projects/python-ufile/badge/?version=latest
        :target: https://python-ufile.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/AriaBagheri/python_ufile/shield.svg
     :target: https://pyup.io/repos/github/AriaBagheri/python_ufile/
     :alt: Updates



Python sdk for downloading/uploading to ufile.io both as a guest and with an API key


* Free software: MIT license
* Documentation: https://python-ufile.readthedocs.io.


Features
--------

Upload files to ufile.io as a guest
Download files from ufile.io with an API_KEY
Get file direct link from ufile.io with an API_KEY


Credits
-------
This package was coded in it's entirety by Aria Bagheri.

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
